\name{idn}
\alias{idn}

\title{
Multidimensional poverty evaluation (only Identification Function)
}
\description{
Given a partial order (arguments \code{profiles} for the set of profiles and/or
\code{zeta} for the incidence matrix) a selected \code{threshold},
the function returns an object of S3 class \code{parsec}, a list of objects described in
Value section. This function retuns only the identification function. See \link{evaluation}
to obtain also the gaps and the inequality measures. This function is a simplified and faster version
to obtain only the identification function.

Results are obtained by uniform sampling of the linear extensions of the poset,
by using the Bubley Dyer (1999) algorithm.
}
\usage{
idn(
    profiles = NULL,
    threshold,
    error = 10^(-3),
    zeta = getzeta(profiles),
    weights = {
        if (!is.null(profiles)) 
            profiles$freq
        else rep(1, nrow(zeta))
    },
    linext = lingen(zeta),
    nit = floor({
        n <- nrow(zeta)
        n^5 * log(n) + n^4 * log(error^(-1))
    }),
    maxint = 2^31 - 1
)
}

\arguments{
  \item{profiles}{
an object of S3 class \code{wprof}.
}
  \item{threshold}{
a vector to select profiles as threshold. It can be a vector of indexes (numeric),
a vector of profiles names (character) or a boolean vector as long as the number of
profiles.
}
  \item{error}{
the error of approximation of the frequencies to the uniformity to sample the
linear extensions.
}
  \item{zeta}{
the incidence matrix of the poset. An object of S3 class \code{incidence}.
By default extracted by \code{profiles} and the orders of the variables modalities.
}
  \item{weights}{
weights to assign to profiles. If the argument \code{profiles} is not \code{NULL},
by default weights are equal to profiles frequencies, else, by default weights are
set equal to 1.
}
  \item{linext}{
the initializing linear extension, by default generated by \code{lingen(zeta)},
but it can be forced by the user through a ranks vector.
}
  \item{nit}{
Number Of Iterations, by default evaluated from a formula of Karzanov and Khachiyan
from the number of profiles and the argument \code{error} (see Bubley and Dyer, 1999).
The user can change it, but the results will not comply the defined \code{error}.
}
  \item{maxint}{
Maximum integer. By default the maximum integer obtainable in a 32bit system.
This argument is used to groups the iterations and run different times the compiled
C library, in order to avoid memory indexing problems. Therefore the user can
set a lower value to \code{maxint} in case of low RAM availability. Furthermore,
during the evaluation, a progress bar will appear indicating the relative number
of iterations groups evaluated.
}
}

\value{
\item{profiles}{an object of S3 class \code{wprof} reporting the poset profiles
and their frequencies.}

\item{number_of_profiles}{number of profiles.}

\item{number_of_variables}{number of variables.}

\item{incidence}{S3 class \code{incidence}, the incidence matrix of the poset.}

\item{cover}{S3 class \code{cover}, the cover matrix of the poset.}

\item{threshold}{boolean vector indicating whether a profile belongs to the threshold.}

\item{number_of_iterations}{number of iterations performed by the Bubley Dyer algorithm.}

\item{rank_relative_frequencies}{matrix that by rows reports the relative
frequencies distribution of the ranks for each profile.}

\item{threshold_relative_frequencies}{vector that reports the relative frequency
of the times a profile is used as threshold in the sampled linear extensions.
This result is useful for posterior valuation of the poset threshold.}

\item{profiles_weights}{vector of weights assigned to each profile.}

\item{edges_weights}{matrix of distances between profiles, used to evaluate the
measures of gap.}

\item{identification_function}{vector that reports the relative frequency of times
that a profile is equal or lower than the threshold of the linear extension.}

\item{point_absolute_poverty_gap}{\code{NA} use \link{evaluation} to obtain this result.}

\item{point_relative_poverty_gap}{\code{NA} use \link{evaluation} to obtain this result.}

\item{point_absolute_wealth_gap}{\code{NA} use \link{evaluation} to obtain this result.}

\item{point_relative_wealth_gap}{\code{NA} use \link{evaluation} to obtain this result.}

\item{poverty_gap}{\code{NA} use \link{evaluation} to obtain this result.}

\item{wealth_gap}{\code{NA} use \link{evaluation} to obtain this result.}

\item{inequality}{\code{NA} use \link{evaluation} to obtain this result.}
}
\references{
Bubley R., Dyer M. (1999), Faster random generation of linear extensions, Discrete Math., 201, 81-88.

Fattore M., Arcagni A. (2013), \href{http://meetings.sis-statistica.org/index.php/sis2013/ALV/paper/view/2633}{Measuring multidimensional polarization with ordinal data}, SIS 2013 Statistical Conference, BES-M3.1 - The BES and the challenges of constructing composite indicators dealing with equity and sustainability
}
\examples{
profiles <- var2prof(varlen = c(3, 2, 4))
threshold <- c("311", "112")

res <- idn(profiles, threshold, maxint = 10^5)

summary(res)
plot(res)
}